summaryrefslogtreecommitdiffstats
path: root/lib/kformula/bracketelement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kformula/bracketelement.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/bracketelement.h')
-rw-r--r--lib/kformula/bracketelement.h124
1 files changed, 62 insertions, 62 deletions
diff --git a/lib/kformula/bracketelement.h b/lib/kformula/bracketelement.h
index a929c04b..98f515a1 100644
--- a/lib/kformula/bracketelement.h
+++ b/lib/kformula/bracketelement.h
@@ -21,8 +21,8 @@
#ifndef BRACKETELEMENT_H
#define BRACKETELEMENT_H
-#include <qpoint.h>
-#include <qsize.h>
+#include <tqpoint.h>
+#include <tqsize.h>
#include "basicelement.h"
@@ -40,7 +40,7 @@ class SingleContentElement : public BasicElement {
SingleContentElement& operator=( const SingleContentElement& ) { return *this; }
public:
- SingleContentElement(BasicElement* parent = 0);
+ SingleContentElement(BasicElement* tqparent = 0);
~SingleContentElement();
SingleContentElement( const SingleContentElement& );
@@ -48,9 +48,9 @@ public:
/**
* @returns the character that represents this element. Used for
* parsing a sequence.
* This is guaranteed to be QChar::null for all non-text elements.
*/
- virtual QChar getCharacter() const;
+ virtual TQChar getCharacter() const;
/**
* Sets the cursor and returns the element the point is in.
@@ -59,10 +59,10 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
/**
- * Dispatch this FontCommand to all our TextElement children.
+ * Dispatch this FontCommand to all our TextElement tqchildren.
*/
virtual void dispatchFontCommand( FontCommand* cmd );
@@ -95,12 +95,12 @@ public:
virtual void moveDown(FormulaCursor* cursor, BasicElement* from);
/**
- * Removes all selected children and returns them. Places the
- * cursor to where the children have been.
+ * Removes all selected tqchildren and returns them. Places the
+ * cursor to where the tqchildren have been.
*
* We remove ourselve if we are requested to remove our content.
*/
- virtual void remove(FormulaCursor*, QPtrList<BasicElement>&, Direction);
+ virtual void remove(FormulaCursor*, TQPtrList<BasicElement>&, Direction);
/**
* Moves the cursor to a normal place where new elements
@@ -110,7 +110,7 @@ public:
// main child
//
- // If an element has children one has to become the main one.
+ // If an element has tqchildren one has to become the main one.
virtual SequenceElement* getMainChild();
@@ -125,24 +125,24 @@ protected:
/**
* Appends our attributes to the dom element.
*/
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
- virtual void writeMathMLContent( QDomDocument& doc,
- QDomElement& element,
+ virtual void writeMathMLContent( TQDomDocument& doc,
+ TQDomElement& element,
bool oasisFormat ) const;
/**
* Reads our content from the node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual bool readContentFromDom(QDomNode& node);
+ virtual bool readContentFromDom(TQDomNode& node);
/**
* Reads our content from the MathML node. Sets the node to the next node
* that needs to be read.
* Returns false if it failed.
*/
- virtual int readContentFromMathMLDom(QDomNode& node);
+ virtual int readContentFromMathMLDom(TQDomNode& node);
SequenceElement* getContent() { return content; }
@@ -166,7 +166,7 @@ public:
enum { contentPos };
BracketElement(SymbolType left = EmptyBracket, SymbolType right = EmptyBracket,
- BasicElement* parent = 0);
+ BasicElement* tqparent = 0);
~BracketElement();
BracketElement( const BracketElement& );
@@ -196,11 +196,11 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& context,
ContextStyle::TextStyle tstyle,
@@ -208,16 +208,16 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
protected:
@@ -226,23 +226,23 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "BRACKET"; }
+ virtual TQString getTagName() const { return "BRACKET"; }
/**
* Reads our attributes from the element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromDom(QDomElement element);
+ virtual bool readAttributesFromDom(TQDomElement element);
- virtual void writeDom(QDomElement element);
+ virtual void writeDom(TQDomElement element);
- virtual QString getElementName() const { return "mfenced"; }
- virtual void writeMathMLAttributes( QDomElement& element ) const;
+ virtual TQString getElementName() const { return "mfenced"; }
+ virtual void writeMathMLAttributes( TQDomElement& element ) const;
/**
* Reads our attributes from the MathML element.
* Returns false if it failed.
*/
- virtual bool readAttributesFromMathMLDom(const QDomElement& element);
+ virtual bool readAttributesFromMathMLDom(const TQDomElement& element);
/**
* Reads our content from the MathML node. Sets the node to the next node
@@ -250,35 +250,35 @@ protected:
* (e. g. for fence operators).
* Returns the number of nodes processed or -1 if it failed.
*/
- virtual int readContentFromMathMLDom(QDomNode& node);
+ virtual int readContentFromMathMLDom(TQDomNode& node);
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
private:
/**
* @return a LaTex string for the given symbol
*/
- QString latexString(char);
+ TQString latexString(char);
/**
* Set left and right types in operator fences
* @param open if true set SymbolType for open (left) bracket,
* otherwise set for close (right) bracket.
*/
- int operatorType( QDomNode& node, bool open );
+ int operatorType( TQDomNode& node, bool open );
/**
* Search through the nodes to find the close operator to match current
* open bracket.
*/
- int searchOperator( const QDomNode& node );
+ int searchOperator( const TQDomNode& node );
/**
* The brackets we are showing.
@@ -289,7 +289,7 @@ private:
SymbolType leftType;
SymbolType rightType;
- QString m_separators;
+ TQString m_separators;
bool m_operator;
bool m_customLeft;
bool m_customRight;
@@ -303,7 +303,7 @@ class OverlineElement : public SingleContentElement {
OverlineElement& operator=( const OverlineElement& ) { return *this; }
public:
- OverlineElement(BasicElement* parent = 0);
+ OverlineElement(BasicElement* tqparent = 0);
~OverlineElement();
OverlineElement( const OverlineElement& );
@@ -322,7 +322,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& context,
ContextStyle::TextStyle tstyle,
@@ -330,26 +330,26 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
- virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false ) const;
+ virtual void writeMathML( TQDomDocument& doc, TQDomNode& tqparent, bool oasisFormat = false ) const;
protected:
@@ -358,7 +358,7 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "OVERLINE"; }
+ virtual TQString getTagName() const { return "OVERLINE"; }
private:
};
@@ -370,7 +370,7 @@ private:
class UnderlineElement : public SingleContentElement {
UnderlineElement& operator=( const UnderlineElement& ) { return *this; }
public:
- UnderlineElement(BasicElement* parent = 0);
+ UnderlineElement(BasicElement* tqparent = 0);
~UnderlineElement();
UnderlineElement( const UnderlineElement& );
@@ -389,7 +389,7 @@ public:
/**
* Calculates our width and height and
- * our children's parentPosition.
+ * our tqchildren's tqparentPosition.
*/
virtual void calcSizes( const ContextStyle& context,
ContextStyle::TextStyle tstyle,
@@ -397,26 +397,26 @@ public:
StyleAttributes& style );
/**
* Draws the whole element including its children.
* The `parentOrigin' is the point this element's parent starts.
* We can use our parentPosition to get our own origin then.
*/
- virtual void draw( QPainter& painter, const LuPixelRect& r,
+ virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& parentOrigin );
+ const LuPixelPoint& tqparentOrigin );
/**
* @returns the latex representation of the element and
- * of the element's children
+ * of the element's tqchildren
*/
- virtual QString toLatex();
+ virtual TQString toLatex();
- virtual QString formulaString();
+ virtual TQString formulaString();
- virtual void writeMathML( QDomDocument& doc, QDomNode& parent, bool oasisFormat = false ) const;
+ virtual void writeMathML( TQDomDocument& doc, TQDomNode& tqparent, bool oasisFormat = false ) const;
protected:
@@ -425,7 +425,7 @@ protected:
/**
* Returns the tag name of this element type.
*/
- virtual QString getTagName() const { return "UNDERLINE"; }
+ virtual TQString getTagName() const { return "UNDERLINE"; }
private:
};
@@ -48,9 +48,9 @@ public:
* @returns the character that represents this element. Used for
* parsing a sequence.
- * This is guaranteed to be QChar::null for all non-text elements.
+ * This is guaranteed to be TQChar::null for all non-text elements.
*/
@@ -208,16 +208,16 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/
@@ -330,26 +330,26 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/
@@ -397,26 +397,26 @@ public:
StyleAttributes& style );
/**
- * Draws the whole element including its children.
- * The `parentOrigin' is the point this element's parent starts.
- * We can use our parentPosition to get our own origin then.
+ * Draws the whole element including its tqchildren.
+ * The `tqparentOrigin' is the point this element's tqparent starts.
+ * We can use our tqparentPosition to get our own origin then.
*/